"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorWithTask = exports.ParsedPayloadSchemaError = exports.AutoYieldRateLimitError = exports.AutoYieldWithCompletedTaskExecutionError = exports.AutoYieldExecutionError = exports.YieldExecutionError = exports.CanceledWithTaskError = exports.RetryWithTaskError = exports.ResumeWithParallelTaskError = exports.ResumeWithTaskError = void 0;
exports.isTriggerError = isTriggerError;
const effect_1 = require("effect");
class ResumeWithTaskError extends effect_1.Data.TaggedError("ResumeWithTaskError") {
    constructor(task) {
        super({ task });
    }
}
exports.ResumeWithTaskError = ResumeWithTaskError;
class ResumeWithParallelTaskError extends effect_1.Data.TaggedError("ResumeWithTaskError") {
    constructor(task, childErrors) {
        super({ task, childErrors });
    }
}
exports.ResumeWithParallelTaskError = ResumeWithParallelTaskError;
class RetryWithTaskError extends effect_1.Data.TaggedError("RetryWithTaskError") {
    constructor(cause, task, retryAt) {
        super({ cause, task, retryAt });
    }
}
exports.RetryWithTaskError = RetryWithTaskError;
class CanceledWithTaskError extends effect_1.Data.TaggedError("CanceledWithTaskError") {
    constructor(task) {
        super({ task });
    }
}
exports.CanceledWithTaskError = CanceledWithTaskError;
class YieldExecutionError extends effect_1.Data.TaggedError("YieldExecutionError") {
    constructor(key) {
        super({ key });
    }
}
exports.YieldExecutionError = YieldExecutionError;
class AutoYieldExecutionError extends effect_1.Data.TaggedError("YieldExecutionError") {
    constructor(location, timeRemaining, timeElapsed) {
        super({ location, timeRemaining, timeElapsed });
    }
}
exports.AutoYieldExecutionError = AutoYieldExecutionError;
class AutoYieldWithCompletedTaskExecutionError extends effect_1.Data.TaggedError("AutoYieldWithCompletedTaskExecutionError") {
    constructor(id, properties, data, output) {
        super({ id, properties, data, output });
    }
}
exports.AutoYieldWithCompletedTaskExecutionError = AutoYieldWithCompletedTaskExecutionError;
class AutoYieldRateLimitError extends effect_1.Data.TaggedError("AutoYieldRateLimitError") {
    constructor(resetAtTimestamp) {
        super({ resetAtTimestamp });
    }
}
exports.AutoYieldRateLimitError = AutoYieldRateLimitError;
class ParsedPayloadSchemaError extends effect_1.Data.TaggedError("ParsedPayloadSchemaError") {
    constructor(schemaErrors) {
        super({ schemaErrors });
    }
}
exports.ParsedPayloadSchemaError = ParsedPayloadSchemaError;
/** Use this function if you're using a `try/catch` block to catch errors.
 * It checks if a thrown error is a special internal error that you should ignore.
 * If this returns `true` then you must rethrow the error: `throw err;`
 * @param err The error to check
 * @returns `true` if the error is a Trigger Error, `false` otherwise.
 */
function isTriggerError(err) {
    return (err instanceof ResumeWithTaskError ||
        err instanceof RetryWithTaskError ||
        err instanceof CanceledWithTaskError ||
        err instanceof YieldExecutionError ||
        err instanceof AutoYieldExecutionError ||
        err instanceof AutoYieldWithCompletedTaskExecutionError ||
        err instanceof AutoYieldRateLimitError ||
        err instanceof ResumeWithParallelTaskError);
}
// This error isn't an internal error but it can be used by the user to figure out which task caused the error
class ErrorWithTask extends effect_1.Data.TaggedError("ErrorWithTask") {
    constructor(cause, message) {
        super({ cause, message });
    }
}
exports.ErrorWithTask = ErrorWithTask;
//# sourceMappingURL=errors.js.map