import { Data } from "effect";
export class ResumeWithTaskError extends Data.TaggedError("ResumeWithTaskError") {
    constructor(task) {
        super({ task });
    }
}
export class ResumeWithParallelTaskError extends Data.TaggedError("ResumeWithTaskError") {
    constructor(task, childErrors) {
        super({ task, childErrors });
    }
}
export class RetryWithTaskError extends Data.TaggedError("RetryWithTaskError") {
    constructor(cause, task, retryAt) {
        super({ cause, task, retryAt });
    }
}
export class CanceledWithTaskError extends Data.TaggedError("CanceledWithTaskError") {
    constructor(task) {
        super({ task });
    }
}
export class YieldExecutionError extends Data.TaggedError("YieldExecutionError") {
    constructor(key) {
        super({ key });
    }
}
export class AutoYieldExecutionError extends Data.TaggedError("YieldExecutionError") {
    constructor(location, timeRemaining, timeElapsed) {
        super({ location, timeRemaining, timeElapsed });
    }
}
export class AutoYieldWithCompletedTaskExecutionError extends Data.TaggedError("AutoYieldWithCompletedTaskExecutionError") {
    constructor(id, properties, data, output) {
        super({ id, properties, data, output });
    }
}
export class AutoYieldRateLimitError extends Data.TaggedError("AutoYieldRateLimitError") {
    constructor(resetAtTimestamp) {
        super({ resetAtTimestamp });
    }
}
export class ParsedPayloadSchemaError extends Data.TaggedError("ParsedPayloadSchemaError") {
    constructor(schemaErrors) {
        super({ schemaErrors });
    }
}
/** Use this function if you're using a `try/catch` block to catch errors.
 * It checks if a thrown error is a special internal error that you should ignore.
 * If this returns `true` then you must rethrow the error: `throw err;`
 * @param err The error to check
 * @returns `true` if the error is a Trigger Error, `false` otherwise.
 */
export function isTriggerError(err) {
    return (err instanceof ResumeWithTaskError ||
        err instanceof RetryWithTaskError ||
        err instanceof CanceledWithTaskError ||
        err instanceof YieldExecutionError ||
        err instanceof AutoYieldExecutionError ||
        err instanceof AutoYieldWithCompletedTaskExecutionError ||
        err instanceof AutoYieldRateLimitError ||
        err instanceof ResumeWithParallelTaskError);
}
// This error isn't an internal error but it can be used by the user to figure out which task caused the error
export class ErrorWithTask extends Data.TaggedError("ErrorWithTask") {
    constructor(cause, message) {
        super({ cause, message });
    }
}
//# sourceMappingURL=errors.js.map