import crypto from "node:crypto";
/** Easily verify webhook payloads when they're using common signing methods. */
export async function verifyRequestSignature({ request, headerName, headerEncoding = "hex", secret, algorithm, }) {
    if (!secret) {
        return {
            success: false,
            reason: "Missing secret – you've probably not set an environment variable.",
        };
    }
    const headerValue = request.headers.get(headerName);
    if (!headerValue) {
        return { success: false, reason: "Missing header" };
    }
    switch (algorithm) {
        case "sha256":
            const success = verifyHmacSha256(headerValue, headerEncoding, secret, await request.text());
            if (success) {
                return {
                    success,
                };
            }
            else {
                return { success: false, reason: "Failed sha256 verification" };
            }
        default:
            throw new Error(`Unsupported algorithm: ${algorithm}`);
    }
}
export function verifyHmacSha256(headerValue, headerEncoding, secret, body) {
    const bodyDigest = crypto.createHmac("sha256", secret).update(body).digest(headerEncoding);
    const signature = headerValue?.replace("hmac-sha256=", "").replace("sha256=", "") ?? "";
    return signature === bodyDigest;
}
//# sourceMappingURL=security.js.map